# pyutilities
Python utilities for terminal display and logs management

## Usage

Lint file before commit
> poetry run black display.py logs.py --diff

Lint docstring
> poetry run ruff check

Test
> poetry run pytest 